@@ -2,13 +2,19 @@
 指定路径，将其中的所有文件复制到指定 path
 """
 
-import os
-import threading
 import multiprocessing
+import os
+import platform
+import shutil
+import threading
+
 from hhcp.utils.chunks import get_chunks
 
+
 def cp_dir(directory, destination, force):
+
     class myThread(threading.Thread):
+
         def __init__(self, threadID, filelist, overwrite):
             threading.Thread.__init__(self)
             self.threadID = threadID
@@ -21,32 +27,43 @@ def cp_dir(directory, destination, force):
             # threadLock.acquire()
             i = 1
             for f in self.filelist:
+                if platform.platform()[:7] == "Windows":
+                    f = [x.replace("\\", "/") for x in f]
+
                 if len(f) == 1:
-                    print("thread ID {}, {}, try create path [{}]".format(self.threadID, i, f[0]))
                     if not os.path.exists(f[0]):
                         try:
                             os.makedirs(f[0])
-                            print("thread ID {}, {}, path [{}] ........ created!".format(self.threadID, i, f[0]))
+                            print(
+                                "thread ID {}, {}, create folder [{}]".format(
+                                    self.threadID, i, f[0]))
                         except FileExistsError:
-                            print("thread ID {}, {}, path [{}] already exists".format(self.threadID, i, f[0]))
+                            pass
                     else:
-                        print("thread ID {}, {}, path [{}] already exists".format(self.threadID, i, f[0]))
+                        pass
                 else:
-                    print("thread ID {}, {}, try copy [{}] to [{}]".format(self.threadID, i, f[0], f[1]))
                     if not os.path.exists(f[1]):
-                        print("thread ID {}, {}, folder [{}] does not exist".format(self.threadID, i, f[1]))
-                        print("thread ID {}, {}, try create path [{}]".format(self.threadID, i, f[1]))
                         try:
                             os.makedirs(f[1])
-                            print("thread ID {}, {}, path [{}] ........ created!".format(self.threadID, i, f[1]))
+                            print("thread ID {}, {}/{}, create folder [{}]".
+                                  format(self.threadID, i, len(self.filelist),
+                                         f[1]))
                         except FileExistsError:
-                            print("thread ID {}, {}, path [{}] already exists".format(self.threadID, i, f[1]))
+                            pass
                     if self.overwrite:
-                        command = "cp {} {}".format(f[0], f[1])
+                        shutil.copy(f[0], f[1])
                     else:
-                        command = "cp -n {} {}".format(f[0], f[1])
-                    os.system(command)
-                    print("thread ID {}, copy [{}] to [{}] ........ successed!".format(self.threadID, i, command))
+                        target_file = os.path.join(f[1], f[0].split("/")[-1])
+                        if os.path.exists(target_file):
+                            print(
+                                "thread ID {}, {}/{}, File [{}] already exist."
+                                .format(self.threadID, i, len(self.filelist),
+                                        target_file))
+                        else:
+                            shutil.copy(f[0], f[1])
+                            print("thread ID {}, {}/{}, copy [{}] to [{}]".
+                                  format(self.threadID, i, len(self.filelist),
+                                         f[0], f[1]))
                 i += 1
 
     thread_num = multiprocessing.cpu_count()
@@ -67,7 +84,10 @@ def cp_dir(directory, destination, force):
             [原始文件绝对路径, 要 cp 到的文件夹的绝对路径]
             """
             for file in files:
-                filelist.append([os.path.join(os.path.abspath(pre), file), os.path.join(absd, absd_suffix)])
+                filelist.append([
+                    os.path.join(os.path.abspath(pre), file),
+                    os.path.join(absd, absd_suffix)
+                ])
         else:
             """
             没有文件的时候，filelist 里存为
@@ -78,7 +98,8 @@ def cp_dir(directory, destination, force):
     filechunks = get_chunks(filelist, thread_num)
     thread_num = len(filechunks)
 
-    threadLock = threading.Lock()
+    # 线程锁
+    # threadLock = threading.Lock()
     threads = []
 
     for i in range(thread_num):
