@@ -1,19 +1,25 @@
 import argparse
 import os
-from argparse import RawTextHelpFormatter
 import sys
+from argparse import RawTextHelpFormatter
+
 from hhcp.cp_dir_multi import cp_dir
 from hhcp.cp_list_multi import cp_list
 
 
+class InvalidInputException(Exception):
+    pass
+
+
 def parse_args():
     parser = argparse.ArgumentParser(
         description="""
-        Provide (a file list)|(a dir) and a destination, cp (all the files in the list)|(the dir) to the destination with multi-thread.
+        Provide (a file list)|(a dir) and a destination,
+        cp (all the files in the list)|(the dir) to the destination
+        with multi-thread.
         This will NOT overwrite existing files on default.\n
         """,
-        formatter_class=RawTextHelpFormatter
-    )
+        formatter_class=RawTextHelpFormatter)
     parser.add_argument(
         "-p",
         help="The path of the directory to be copied.",
@@ -47,6 +53,7 @@ def parse_args():
     )
     if len(sys.argv) == 1:
         parser.print_help()
+        sys.exit()
     return parser.parse_args()
 
 
@@ -54,36 +61,31 @@ def load_config(args):
     """
     Given the arguemnts, load and initialize the configs.
     Args:
-        args (argument): arguments includes `p`, `d`, `n`, `force`
+        args (argument): `p`, `f`, `d`, `n`, `force`, `pre`
     """
     if args.p is not None and args.f is not None:
-        print("Only one of -p and -f could be provided but get two.")
-        sys.exit(0)
+        raise InvalidInputException(
+            "Only one of -p and -f could be provided but get two.")
     elif args.p is None and args.f is None:
-        print("At least one of -p and -f should be provided.")
-        sys.exit(0)
+        raise InvalidInputException(
+            "At least one of -p and -f should be provided.")
     else:
         # 判断 p 是否为合法路径
         if args.p is not None:
             if not os.path.exists(args.p):
-                print("The dir to be copied does not exist.")
-                sys.exit(0)
+                raise FileNotFoundError("The dir to be copied does not exist.")
             elif not os.path.isdir(args.p):
-                print("-p should be a dir.")
-                sys.exit(0)
+                raise InvalidInputException("-p should be a dir.")
         # 判断 f 是否为合法路径
         elif args.f is not None:
             if not os.path.exists(args.f):
-                print("File not found.")
-                sys.exit(0)
+                raise FileNotFoundError("Could not find the filelist.")
     # 判断 d 是否为合法路径
     if args.d is not None:
         if not os.path.isdir(args.d):
-            print("-d should be a dir.")
-            sys.exit(0)
+            raise InvalidInputException("-d should be a dir.")
         if not os.path.exists(args.d):
-            print("The destination dir does not exist.")
-            sys.exit(0)
+            raise FileNotFoundError("The destination dir does not exist.")
     if args.pre is None:
         args.pre = ''
     return args.p, args.f, args.d, args.pre, args.force
